<?php
namespace Claromentis\Mailgun\Model;

$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"] ?: array()) + array("_44e986c04f41" . "a08b56a383c7b" . "3a88ee2" => base64_decode("c2VuZGV" . "y"), "_956cd32298a" . "229f9768f109" . "6f077ace3" => base64_decode("Ym9ke" . "S1wbG" . "Fpbg=" . "="), "_97ea09a7faf27c52c" . "6eff69773df1d8a" => base64_decode("dGlt" . "ZXN0" . "YW1w"), "_a1e707d0" . "2a236dade" . "bd15a45e6" . "5ebdb6" => base64_decode("YXR0YWNobWVudC1j" . "b3VudA=="), "_f589476" . "007fa133" . "f457c3ef" . "29ddfa56" . "6" => base64_decode("VG8" . "="), "_8c575917cbae" . "df1e7efae8493" . "9402bff" => base64_decode("U3Via" . "mVjdA" . "=="), "_d706c160e45bf7434fff82a597" . "6f0e19" => base64_decode("YXJyYXlfa2V5" . "cw=="), "_1d6c68a0262e8fa0bed1215b7224a9" . "8e" => base64_decode("cmVjaXBpZ" . "W50"), "_f39f5346" . "e313e4dd1" . "ac3a7bd80" . "32beda" => base64_decode("c3Vic3RyX2NvbXBhcm" . "U="), "_618a4aeb9fecc4592a4521f34" . "876fa29" => base64_decode("ZnJv" . "bQ=="), "_9c050c786fc87170" . "cbb84fc6a8b13cb6" => base64_decode("YXR0" . "YWNo" . "bWVu" . "dC0="), "_6e1c717" . "cf3cbf1a" . "f982ed74" . "d4336b7f" . "1" => base64_decode("Ym9keS1o" . "dG1s"));
use Claromentis\Core\Mail\Receive\Contract\MailAttachment;
use Claromentis\Core\Mail\Receive\Contract\MailMessage;
use Claromentis\Core\Util\ArrayUtil;




class MailgunMessage implements MailMessage
{
    protected $message_data;
    protected $attachments_data;
    protected $attachments;
    
    
    
    
    
    public function __construct($_a3d82c5df38e194c9c73e3ccb4223bbc = [], $_4e7ab34a53ffb13eb0838003f33034d4 = [])
    {
        $this->message_data = $_a3d82c5df38e194c9c73e3ccb4223bbc;
        $this->attachments = $_4e7ab34a53ffb13eb0838003f33034d4;
        foreach ($GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_d706c160e45b" . "f7434fff82a59" . "76f0e19"]($this->message_data) as $key) {
            if ($key !== $GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_a1e707d" . "02a236da" . "debd15a4" . "5e65ebdb" . "6"] && $GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_f39f5346e313e4dd1ac" . "3a7bd8032beda"]($key, $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_9c050c786fc87170cbb84fc6a8b13c" . "b6"], 0, 11) === 0) {
                $this->attachments[] = new MailgunAttachmentString($key, $this->message_data[$key]);
            }
        }
    }
    
    
    
    
    public function GetRecipientAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_1d6c68a0262e" . "8fa0bed1215b7" . "224a98e"]);
    }
    
    
    
    
    
    
    public function GetFrom() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_618a4aeb9fecc4592a4521" . "f34876fa29"]], null);
    }
    
    
    
    
    
    
    
    public function GetTo() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_f589476007fa133f457c3ef29ddf" . "a566"]], null);
    }
    
    
    
    
    public function GetSubject() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_8c575917cbaedf1e7efae84939402b" . "ff"]);
    }
    
    
    
    
    public function GetBodyHtml() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_6e1c717cf" . "3cbf1af982" . "ed74d4336b" . "7f1"]);
    }
    
    
    
    
    public function GetBodyText() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_956cd32298a229f9768f1096f07" . "7ace3"]);
    }
    
    
    
    
    public function GetDate() : \Date
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = new \Date(ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_97ea09a7faf27c52c6eff6" . "9773df1d8a"]));
        return $_67a0d624aebcceb0abd5ce56a53ff06f;
    }
    
    
    
    
    public function GetSenderAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_44e986c04f41a08b56a38" . "3c7b3a88ee2"]);
    }
    public function GetAttachments()
    {
        return $this->attachments;
    }
}