<?php
namespace Claromentis\Infocapture\Subscriber;

$GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"] ?: array()) + array("_f656816961e85738061" . "41c558b184fe2" => base64_decode("c3Via" . "mVjdA" . "=="), "_bfda889b74ea5" . "61b14325e30e7d" . "75426" => base64_decode("Ym9keV9odG1" . "s"), "_5d40a2cf1c525fb252bf5599e339" . "fdd0" => base64_decode("Tm8gaW5mb2NhcHR1cmUgcHJvamVjdCB3YXMgaWRlbnRpZmllZ" . "CBmb3IgbWFpbDsgc3ViamVjdCAn"), "_618a4aeb9fe" . "cc4592a4521f" . "34876fa29" => base64_decode("ZnJvb" . "Q=="), "_460e1aeb3113a1676ce59a8f4" . "0431d5c" => base64_decode("RmFpbGVkIHRvIHByb2Nlc3MgZW1haWwgZm9yIGluZm9jY" . "XB0dXJlIHByb2plY3Q="), "_67a0d624ae" . "bcceb0abd5c" . "e56a53ff06f" => base64_decode("ZGF0ZQ=" . "="), "_376d30c4" . "0857357a4" . "d4cbb1ffa" . "a25817" => base64_decode("d" . "G" . "8" . "="), "_c3547336" . "4fa7a0502" . "99058f332" . "ec29c1" => base64_decode("ZXhjZ" . "XB0aW" . "9u"), "_ced92d7b391285c8a26846f1" . "f4bd3128" => base64_decode("Ym9keV" . "90ZXh0"), "_e608e5b5c4c34a67ba97ef84c1e1" . "6199" => base64_decode("J" . "w" . "=" . "="), "_a3d82c5df38e194c9c73e3ccb4" . "223bbc" => base64_decode("ZW1haWxfZ" . "GF0YQ=="), "_03b1f0cee835582d1158dce2678b5" . "05c" => base64_decode("U3RhcnRpbmcgaW5mb2Nh" . "cHR1cmUgbWFpbCByZWNl" . "aXZlZCBzdWJzY3JpYmVy"), "project" . "_id" => base64_decode("cHJvamVjdF" . "9pZA=="), "_9b16fa2683" . "095e67d7c8b" . "265a8081d0b" => base64_decode("TWFpbFJlY2" . "VpdmVkRXZl" . "bnRSZWNlaX" . "Zlcg=="));
use Claromentis\Core\Event\EventDispatcherInterface;
use Claromentis\Core\Event\EventSubscriberInterface;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEventType;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEvent;
use Claromentis\Infocapture\Model\MailboxMessage;
use Claromentis\Infocapture\UseCase\GetProjectByEmailAddress;
use Claromentis\Infocapture\UseCase\ProcessEmail;
use Exception;
use Psr\Log\LoggerInterface;
class MailReceivedSubscriber implements EventSubscriberInterface
{
    protected $logger;
    protected $get_project_use_case;
    protected $process_email_use_case;
    public function __construct(LoggerInterface $logger, GetProjectByEmailAddress $_ecd19adac06bcc3637cff9925531a823, ProcessEmail $_33929bbf18079cca22e39e6dbe7eea3c)
    {
        $this->logger = $logger;
        $this->get_project_use_case = $_ecd19adac06bcc3637cff9925531a823;
        $this->process_email_use_case = $_33929bbf18079cca22e39e6dbe7eea3c;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function getSubscribedEvents()
    {
        return [
            
            
            ReceiveMailEventType::RECEIVE_MAIL => $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_9b16fa2683095e67d7c8b265a8081" . "d0b"],
        ];
    }
    
    
    
    
    
    
    public function MailReceivedEventReceiver(ReceiveMailEvent $event, $_5693d84b45564f912e36404cbe8957e8, EventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        $this->logger->info($GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_03b1f0c" . "ee835582" . "d1158dce" . "2678b505" . "c"]);
        $_a9bf694098bca136cc65bf4d2623bc70 = $event->GetMailMessage();
        $_f656816961e8573806141c558b184fe2 = $_a9bf694098bca136cc65bf4d2623bc70->GetSubject();
        
        
        $project = null;
        if ($_a9bf694098bca136cc65bf4d2623bc70 instanceof MailboxMessage) {
            $project = $_a9bf694098bca136cc65bf4d2623bc70->GetProject();
        } else {
            $project = $this->get_project_use_case->GetMailgunProject($_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress());
        }
        if ($project === null) {
            $this->logger->debug($GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_5d40a2cf1c525fb252bf5599" . "e339fdd0"] . $_f656816961e8573806141c558b184fe2 . $GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_e608e5b5c4c34a67ba97ef84c" . "1e16199"]);
            return;
        }
        $_a3d82c5df38e194c9c73e3ccb4223bbc = [$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_618a4aeb9fecc4592a4521f34876fa2" . "9"] => $_a9bf694098bca136cc65bf4d2623bc70->GetSenderAddress(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_376d30c40857357a4d4cbb1ffaa25" . "817"] => $_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress(), $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_f656816961" . "e8573806141" . "c558b184fe2"] => $_f656816961e8573806141c558b184fe2, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_ced92d7b391285c8a" . "26846f1f4bd3128"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyText(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_bfda889b74ea561b14325e30e" . "7d75426"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyHtml(), $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_67a0d624aebcceb0abd5ce56a53ff0" . "6f"] => $_a9bf694098bca136cc65bf4d2623bc70->GetDate()];
        try {
            $this->process_email_use_case->ProcessEmail($project, $_a3d82c5df38e194c9c73e3ccb4223bbc, $_a9bf694098bca136cc65bf4d2623bc70->GetAttachments());
        } catch (Exception $_c35473364fa7a050299058f332ec29c1) {
            $this->logger->warning($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_460e1aeb3113a1676ce59a8f40" . "431d5c"], [$GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["project_i" . "d"] => $project->GetId(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_a3d82c5" . "df38e194" . "c9c73e3c" . "cb4223bb" . "c"] => $_a3d82c5df38e194c9c73e3ccb4223bbc, $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_c35473364f" . "a7a05029905" . "8f332ec29c1"] => $_c35473364fa7a050299058f332ec29c1]);
        }
    }
}